@@ -87,6 +87,7 @@ struct GSListenerPrivate {
     guint           session_idle : 1;
     guint           active : 1;
     guint           activation_enabled : 1;
+    guint           sleep_activation_enabled : 1;
     guint           throttled : 1;
     GHashTable     *inhibitors;
     GHashTable     *throttlers;
@@ -127,6 +128,7 @@ enum {
     PROP_ACTIVE,
     PROP_SESSION_IDLE,
     PROP_ACTIVATION_ENABLED,
+    PROP_SLEEP_ACTIVATION_ENABLED,
 };
 
 enum {
@@ -494,6 +496,16 @@ gs_listener_set_activation_enabled (GSListener *listener,
     }
 }
 
+void
+gs_listener_set_sleep_activation_enabled (GSListener *listener,
+                                          gboolean    enabled) {
+    g_return_if_fail (GS_IS_LISTENER (listener));
+
+    if (listener->priv->sleep_activation_enabled != enabled) {
+        listener->priv->sleep_activation_enabled = enabled;
+    }
+}
+
 static dbus_bool_t
 listener_property_set_bool (GSListener  *listener,
                             guint        prop_id,
@@ -1483,6 +1495,26 @@ listener_dbus_handle_system_message (DBusConnection *connection,
                 g_signal_emit (listener, signals[LOCK], 0);
             }
 
+            return DBUS_HANDLER_RESULT_HANDLED;
+        } else if (dbus_message_is_signal (message, SYSTEMD_LOGIND_INTERFACE, "PrepareForSleep")) {
+            gboolean  active = 0;
+            DBusError error;
+
+            dbus_error_init (&error);
+            dbus_message_get_args (message, &error, DBUS_TYPE_BOOLEAN, &active, DBUS_TYPE_INVALID);
+            if (active) {
+                if (listener->priv->sleep_activation_enabled) {
+                    gs_debug ("Logind requested session lock");
+                    g_signal_emit (listener, signals[LOCK], 0);
+                } else {
+                    gs_debug ("Logind requested session lock, but lock on suspend is disabled");
+                }
+            } else {
+                gs_debug ("Logind requested session unlock");
+                // FIXME: there is no signal to request password prompt
+                g_signal_emit (listener, signals[SHOW_MESSAGE], 0, NULL, NULL, NULL);
+            }
+
             return DBUS_HANDLER_RESULT_HANDLED;
         } else if (dbus_message_is_signal (message, DBUS_INTERFACE_PROPERTIES, "PropertiesChanged")) {
             if (_listener_message_path_is_our_session (listener, message)) {
@@ -1784,6 +1816,9 @@ gs_listener_set_property (GObject      *object,
         case PROP_ACTIVATION_ENABLED:
             gs_listener_set_activation_enabled (self, g_value_get_boolean (value));
             break;
+        case PROP_SLEEP_ACTIVATION_ENABLED:
+            gs_listener_set_sleep_activation_enabled (self, g_value_get_boolean (value));
+            break;
         default:
             G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
             break;
@@ -1809,6 +1844,9 @@ gs_listener_get_property (GObject    *object,
         case PROP_ACTIVATION_ENABLED:
             g_value_set_boolean (value, self->priv->activation_enabled);
             break;
+        case PROP_SLEEP_ACTIVATION_ENABLED:
+            g_value_set_boolean (value, self->priv->sleep_activation_enabled);
+            break;
         default:
             G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
             break;
@@ -1913,6 +1951,13 @@ gs_listener_class_init (GSListenerClass *klass) {
                                                            NULL,
                                                            TRUE,
                                                            G_PARAM_READWRITE));
+    g_object_class_install_property (object_class,
+                                     PROP_SLEEP_ACTIVATION_ENABLED,
+                                     g_param_spec_boolean ("sleep-activation-enabled",
+                                                           NULL,
+                                                           NULL,
+                                                           TRUE,
+                                                           G_PARAM_READWRITE));
 }
 
 static gboolean
@@ -2028,6 +2073,12 @@ gs_listener_acquire (GSListener  *listener,
                                 ",interface='"SYSTEMD_LOGIND_SESSION_INTERFACE"'"
                                 ",member='Lock'",
                                 NULL);
+            dbus_bus_add_match (listener->priv->system_connection,
+                                "type='signal'"
+                                ",sender='"SYSTEMD_LOGIND_SERVICE"'"
+                                ",interface='"SYSTEMD_LOGIND_INTERFACE"'"
+                                ",member='PrepareForSleep'",
+                                NULL);
             dbus_bus_add_match (listener->priv->system_connection,
                                 "type='signal'"
                                 ",sender='"SYSTEMD_LOGIND_SERVICE"'"
