@@ -29,6 +29,8 @@
 #include <gdk/gdkx.h>
 #include <gio/gio.h>
 
+#include <X11/extensions/dpms.h>
+
 #include "gs-debug.h"
 #include "gs-grab.h"
 #include "gs-fade.h"
@@ -88,6 +90,8 @@ struct GSManagerPrivate {
     GSGrab         *grab;
     GSFade         *fade;
     guint           unfade_idle_id;
+    guint           deepsleep_idle_id;
+    gboolean        deepsleep;
 };
 
 enum {
@@ -122,6 +126,10 @@ static guint         signals[LAST_SIGNAL] = { 0, };
 
 G_DEFINE_TYPE_WITH_PRIVATE (GSManager, gs_manager, G_TYPE_OBJECT)
 
+static void         remove_deepsleep_idle   (GSManager *manager);
+static gboolean     deepsleep_idle          (GSManager *manager);
+static void         add_deepsleep_idle      (GSManager *manager);
+
 static void
 manager_add_job_for_window (GSManager *manager,
                             GSWindow  *window,
@@ -396,13 +404,13 @@ gs_manager_set_lock_active (GSManager *manager,
 
     g_return_if_fail (GS_IS_MANAGER (manager));
 
-    gs_debug ("Setting lock active: %d", lock_active);
 
     if (manager->priv->lock_active != lock_active) {
         manager->priv->lock_active = lock_active;
     }
 
     for (l = manager->priv->windows; l; l = l->next) {
+        gs_debug ("Setting lock active: %d", lock_active);
         gs_window_set_lock_active(l->data, lock_active);
     }
 }
@@ -487,20 +495,6 @@ gs_manager_set_lock_enabled (GSManager *manager,
     }
 }
 
-void
-gs_manager_get_lock_with_saver_enabled (GSManager *manager,
-                             gboolean  *lock_with_saver_enabled) {
-    if (lock_with_saver_enabled != NULL) {
-        *lock_with_saver_enabled = FALSE;
-    }
-
-    g_return_if_fail (GS_IS_MANAGER (manager));
-
-    if (lock_with_saver_enabled != NULL) {
-        *lock_with_saver_enabled = manager->priv->lock_with_saver_enabled;
-    }
-}
-
 void
 gs_manager_set_lock_with_saver_enabled (GSManager *manager,
                              gboolean   lock_with_saver_enabled) {
@@ -561,6 +555,7 @@ activate_lock_timeout (GSManager *manager) {
     if (manager->priv->lock_enabled &&
             manager->priv->lock_with_saver_enabled)
     {
+        gs_debug ("Locking screen after idling timeout");
         gs_manager_set_lock_active (manager, TRUE);
     }
 
@@ -580,6 +575,17 @@ remove_lock_timer (GSManager *manager) {
 static void
 add_lock_timer (GSManager *manager,
                 glong      timeout) {
+    if (!manager->priv->lock_enabled)
+        return;
+    if (!manager->priv->lock_with_saver_enabled)
+        return;
+
+    gboolean locked;
+    gs_manager_get_lock_active (manager, &locked);
+    if (locked)
+        return;
+
+    gs_debug ("Scheduling screen lock after screensaver is idling for %i sec", timeout / 1000);
     manager->priv->lock_timeout_id = g_timeout_add (timeout,
                                                     (GSourceFunc)activate_lock_timeout,
                                                     manager);
@@ -1012,13 +1018,6 @@ gs_manager_class_init (GSManagerClass *klass) {
                                                            G_PARAM_READWRITE));
 }
 
-static void
-on_bg_changed (XfceBG    *bg,
-               GSManager *manager) {
-    // TODO: cleanup unused code
-    // gs_debug ("background changed");
-}
-
 static void
 gs_manager_init (GSManager *manager) {
     manager->priv = gs_manager_get_instance_private (manager);
@@ -1029,12 +1028,9 @@ gs_manager_init (GSManager *manager) {
 
     manager->priv->bg = xfce_bg_new ();
 
-    g_signal_connect (manager->priv->bg,
-                      "changed",
-                      G_CALLBACK (on_bg_changed),
-                      manager);
-
     xfce_bg_load_from_preferences (manager->priv->bg, NULL);
+
+    add_deepsleep_idle(manager);
 }
 
 static void
@@ -1101,6 +1097,10 @@ find_window_at_pointer (GSManager *manager) {
     if (window == NULL) {
         gs_debug ("WARNING: Could not find the GSWindow for display %s",
                   gdk_display_get_name (display));
+        /* bail if there are no windows available */
+        if (manager->priv->windows == NULL)
+            return NULL;
+
         /* take the first one */
         window = manager->priv->windows->data;
     } else {
@@ -1122,6 +1122,9 @@ gs_manager_show_message (GSManager  *manager,
 
     /* Find the GSWindow that contains the pointer */
     window = find_window_at_pointer (manager);
+    if (window == NULL)
+        return;
+
     gs_window_show_message (window, summary, body, icon);
     gs_manager_request_unlock (manager);
 }
@@ -1192,6 +1195,47 @@ add_unfade_idle (GSManager *manager) {
     manager->priv->unfade_idle_id = g_timeout_add (500, (GSourceFunc)unfade_idle, manager);
 }
 
+static void
+remove_deepsleep_idle (GSManager *manager) {
+    if (manager->priv->deepsleep_idle_id > 0) {
+        g_source_remove (manager->priv->deepsleep_idle_id);
+        manager->priv->deepsleep_idle_id = 0;
+    }
+}
+
+static gboolean
+deepsleep_idle (GSManager *manager) {
+    BOOL state;
+    CARD16 power_level;
+
+    if (!DPMSInfo(gdk_x11_get_default_xdisplay(), &power_level, &state)) {
+        if (manager->priv->deepsleep) {
+            gs_debug ("Unable to read DPMS state, exiting deep sleep");
+            manager->priv->deepsleep = FALSE;
+        }
+        return TRUE;
+    }
+
+    if (power_level == DPMSModeOn) {
+        if (manager->priv->deepsleep) {
+            gs_debug ("Exiting deep sleep");
+            manager->priv->deepsleep = FALSE;
+        }
+    } else if (!manager->priv->throttled && !manager->priv->deepsleep) {
+        gs_debug ("Entering deep sleep, suspending jobs");
+        manager->priv->deepsleep = TRUE;
+        manager_suspend_jobs (manager);
+    }
+
+    return TRUE;
+}
+
+static void
+add_deepsleep_idle (GSManager *manager) {
+    remove_deepsleep_idle(manager);
+    manager->priv->deepsleep_idle_id = g_timeout_add (15000, (GSourceFunc)deepsleep_idle, manager);
+}
+
 static gboolean
 window_map_event_cb (GSWindow  *window,
                      GdkEvent  *event,
@@ -1217,47 +1261,11 @@ window_unmap_cb (GSWindow  *window,
     gs_debug ("Window unmapped!");
 }
 
-static void
-apply_background_to_window (GSManager *manager,
-                            GSWindow  *window) {
-    cairo_surface_t *surface;
-    GdkMonitor      *monitor;
-    GdkRectangle     geometry;
-    int              width, m_width;
-    int              height, m_height;
-
-    monitor = gs_window_get_monitor (window);
-
-    xfce_bg_load_from_preferences (manager->priv->bg, monitor);
-
-    if (manager->priv->bg == NULL) {
-        gs_debug ("No background available");
-        gs_window_set_background_surface (window, NULL);
-    }
-
-    gdk_monitor_get_geometry (monitor, &geometry);
-    m_width = geometry.width;
-    m_height = geometry.height;
-    gtk_widget_get_preferred_width (GTK_WIDGET (window), &width, NULL);
-    gtk_widget_get_preferred_height (GTK_WIDGET (window), &height, NULL);
-    gs_debug ("Creating background (Screen: w:%d h:%d, Monitor: w:%d h: %d)", width, height, m_width, m_height);
-    surface = xfce_bg_create_surface (manager->priv->bg,
-                                      gs_window_get_gdk_window (window),
-                                      width,
-                                      height,
-                                      m_width,
-                                      m_height);
-    gs_window_set_background_surface (window, surface);
-    cairo_surface_destroy (surface);
-}
-
 static void
 manager_show_window (GSManager *manager,
                      GSWindow  *window) {
     GSJob *job;
 
-    apply_background_to_window (manager, window);
-
     job = gs_job_new_for_widget (gs_window_get_drawing_area (window));
 
     manager_select_theme_for_job (manager, job);
@@ -1485,6 +1493,33 @@ gs_manager_create_window_for_monitor (GSManager  *manager,
     }
 }
 
+static gboolean
+gs_manager_is_real_monitor (GdkMonitor *monitor) {
+    // avoiding some weird gdk bug
+    // federico> avb: or if you don't care about a little unexplained messiness,
+    //                just discard monitors where both fields are null? :)
+    if (gdk_monitor_get_manufacturer(monitor) == NULL && gdk_monitor_get_model(monitor) == NULL)
+        return FALSE;
+    return TRUE;
+}
+
+static int
+gs_manager_get_n_monitors (GdkDisplay *display) {
+    // Since gdk_display_get_n_monitors return wrong monitor count
+    // this is a workaround for the problem
+    GdkMonitor *monitor;
+    int        n_monitors;
+    int        i, count = 0;
+
+    n_monitors = gdk_display_get_n_monitors (display);
+    for (i = 0; i < n_monitors; i++) {
+        monitor = gdk_display_get_monitor(display, i);
+        if (gs_manager_is_real_monitor (monitor))
+            count++;
+    }
+    return count;
+}
+
 static void
 on_display_monitor_added (GdkDisplay *display,
                           GdkMonitor *monitor,
@@ -1492,7 +1527,9 @@ on_display_monitor_added (GdkDisplay *display,
     GSList     *l;
     int         n_monitors;
 
-    n_monitors = gdk_display_get_n_monitors (display);
+    g_return_if_fail (gs_manager_is_real_monitor(monitor));
+
+    n_monitors = gs_manager_get_n_monitors (display);
 
     gs_debug ("Monitor added on display %s, now there are %d",
               gdk_display_get_name (display), n_monitors);
@@ -1539,7 +1576,9 @@ on_display_monitor_removed (GdkDisplay *display,
     int         n_monitors;
     GdkMonitor *last_monitor = NULL;
 
-    n_monitors = manager->priv->last_monitor_count = gdk_display_get_n_monitors (display);
+    g_return_if_fail (gs_manager_is_real_monitor(monitor));
+
+    n_monitors = manager->priv->last_monitor_count = gs_manager_get_n_monitors (display);
 
     gs_debug ("Monitor removed on display %s, now there are %d",
               gdk_display_get_name (display), n_monitors);
@@ -1634,7 +1673,8 @@ gs_manager_finalize (GObject *object) {
     g_free (manager->priv->status_message);
 
     remove_unfade_idle (manager);
-    remove_timers (manager);
+    remove_deepsleep_idle (manager);
+    remove_timers(manager);
 
     gs_grab_release (manager->priv->grab, TRUE);
 
@@ -1872,7 +1912,6 @@ gs_manager_request_unlock (GSManager *manager) {
 
     /* Find the GSWindow that contains the pointer */
     window = find_window_at_pointer (manager);
-        apply_background_to_window (manager, window);
     gs_window_request_unlock (window);
 
     return TRUE;
