@@ -1593,6 +1593,7 @@ popup_dialog (GSWindow *window) {
     window->priv->dialog_quit_requested = FALSE;
     window->priv->dialog_shake_in_progress = FALSE;
 
+    gs_debug ("Executing %s", command->str);
     result = spawn_on_window (window,
                               command->str,
                               &window->priv->lock_pid,
@@ -1619,7 +1620,6 @@ void
 gs_window_request_unlock (GSWindow *window) {
     g_return_if_fail (GS_IS_WINDOW (window));
 
-    gs_debug ("Requesting unlock");
 
     if (!gtk_widget_get_visible (GTK_WIDGET (window))) {
         gs_debug ("Request unlock but window is not visible!");
@@ -1638,7 +1638,6 @@ gs_window_request_unlock (GSWindow *window) {
     if (window->priv->popup_dialog_idle_id == 0) {
         add_popup_dialog_idle (window);
     }
-
     window_set_dialog_up (window, TRUE);
 }
 
@@ -1789,6 +1788,8 @@ gs_window_set_status_message (GSWindow   *window,
 void
 gs_window_set_monitor (GSWindow   *window,
                        GdkMonitor *monitor) {
+    gint tmp;
+
     g_return_if_fail (GS_IS_WINDOW (window));
 
     if (window->priv->monitor == monitor) {
@@ -1798,6 +1799,7 @@ gs_window_set_monitor (GSWindow   *window,
     window->priv->monitor = monitor;
 
     gtk_widget_queue_resize (GTK_WIDGET (window));
+    gtk_widget_get_preferred_width (GTK_WIDGET (window), &tmp, &tmp);
 
     g_object_notify (G_OBJECT (window), "monitor");
 }
@@ -2036,6 +2038,10 @@ gs_window_real_size_request (GtkWidget      *widget,
     bin = GTK_BIN (widget);
     child = gtk_bin_get_child (bin);
 
+    // monitor been removed, but we will return it later on
+    if (!GDK_IS_MONITOR (window->priv->monitor))
+        return;
+
     if (child && gtk_widget_get_visible (child)) {
         gtk_widget_get_preferred_size (child, requisition, NULL);
     }
