@@ -17,20 +17,21 @@
  * write to the Free Software Foundation, Inc., 51 Franklin St,
  * Fifth Floor, Boston, MA 02110-1301, USA.
  */
+
 #include <config.h>
 
 #include <memory.h>
 
-#include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk/gdkx.h>
+#include <gtk/gtk.h>
+
 #include <libxfce4util/libxfce4util.h>
 
-#include "xfcekbd-indicator.h"
-#include "xfcekbd-indicator-marshal.h"
-
 #include "xfcekbd-desktop-config.h"
+#include "xfcekbd-indicator.h"
 #include "xfcekbd-indicator-config.h"
+#include "xfcekbd-indicator-marshal.h"
 
 typedef struct _gki_globals {
     XklEngine               *engine;
@@ -45,6 +46,8 @@ typedef struct _gki_globals {
     gchar                  **short_group_names;
     GSList                  *widget_instances;
     GSList                  *images;
+
+    gboolean                 redraw_queued;
 } gki_globals;
 
 struct _XfcekbdIndicatorPrivate {
@@ -78,92 +81,9 @@ static void        xfcekbd_indicator_fill                           (XfcekbdIndi
 static void        xfcekbd_indicator_set_tooltips                   (XfcekbdIndicator *gki,
                                                                      const char       *str);
 
-static void
-xfcekbd_indicator_load_images ()
-{
-    int     i;
-    GSList *image_filename;
-
-    globals.images = NULL;
-    xfcekbd_indicator_config_load_image_filenames (&globals.ind_cfg,
-                            &globals.kbd_cfg);
-
-    if (!globals.ind_cfg.show_flags)
-        return;
-
-    image_filename = globals.ind_cfg.image_filenames;
-
-    for (i = xkl_engine_get_max_num_groups (globals.engine);
-         --i >= 0; image_filename = image_filename->next) {
-        GdkPixbuf *image = NULL;
-        char *image_file = (char *) image_filename->data;
-
-        if (image_file != NULL) {
-            GError *gerror = NULL;
-            image =
-                gdk_pixbuf_new_from_file (image_file, &gerror);
-            if (image == NULL) {
-                GtkWidget *dialog =
-                    gtk_message_dialog_new (NULL,
-                                            GTK_DIALOG_DESTROY_WITH_PARENT,
-                                            GTK_MESSAGE_ERROR,
-                                            GTK_BUTTONS_OK,
-                                            _("There was an error loading an image: %s"),
-                                            gerror->
-                                            message);
-                g_signal_connect (G_OBJECT (dialog),
-                                  "response",
-                                  G_CALLBACK
-                                  (gtk_widget_destroy),
-                                  NULL);
-
-                gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-
-                gtk_widget_show (dialog);
-                g_error_free (gerror);
-            }
-            xkl_debug (150,
-                       "Image %d[%s] loaded -> %p[%dx%d]\n",
-                       i, image_file, image,
-                       gdk_pixbuf_get_width (image),
-                       gdk_pixbuf_get_height (image));
-        }
-        /* We append the image anyway - even if it is NULL! */
-        globals.images = g_slist_append (globals.images, image);
-    }
-}
-
-static void
-xfcekbd_indicator_free_images ()
-{
-    GdkPixbuf *pi;
-    GSList    *img_node;
-
-    xfcekbd_indicator_config_free_image_filenames (&globals.ind_cfg);
-
-    while ((img_node = globals.images) != NULL) {
-        pi = GDK_PIXBUF (img_node->data);
-        /* It can be NULL - some images may be missing */
-        if (pi != NULL) {
-            g_object_unref (pi);
-        }
-        globals.images =
-            g_slist_remove_link (globals.images, img_node);
-        g_slist_free_1 (img_node);
-    }
-}
-
-static void
-xfcekbd_indicator_update_images (void)
-{
-    xfcekbd_indicator_free_images ();
-    xfcekbd_indicator_load_images ();
-}
-
 void
 xfcekbd_indicator_set_tooltips (XfcekbdIndicator *gki,
-                                const char       *str)
-{
+                                const char       *str) {
     g_assert (str == NULL || g_utf8_validate (str, -1, NULL));
 
     gtk_widget_set_tooltip_text (GTK_WIDGET (gki), str);
@@ -178,8 +98,7 @@ xfcekbd_indicator_set_tooltips (XfcekbdIndicator *gki,
 }
 
 void
-xfcekbd_indicator_cleanup (XfcekbdIndicator * gki)
-{
+xfcekbd_indicator_cleanup (XfcekbdIndicator * gki) {
     int          i;
     GtkNotebook *notebook = GTK_NOTEBOOK (gki);
 
@@ -190,8 +109,7 @@ xfcekbd_indicator_cleanup (XfcekbdIndicator * gki)
 }
 
 void
-xfcekbd_indicator_fill (XfcekbdIndicator * gki)
-{
+xfcekbd_indicator_fill (XfcekbdIndicator * gki) {
     int          grp;
     int          total_groups = xkl_engine_get_num_groups (globals.engine);
     GtkNotebook *notebook = GTK_NOTEBOOK (gki);
@@ -209,10 +127,8 @@ xfcekbd_indicator_fill (XfcekbdIndicator * gki)
 
 static gboolean xfcekbd_indicator_key_pressed (GtkWidget        *widget,
                                                GdkEventKey      *event,
-                                               XfcekbdIndicator *gki)
-{
-    switch (event->keyval)
-    {
+                                               XfcekbdIndicator *gki) {
+    switch (event->keyval) {
         case GDK_KEY_KP_Enter:
         case GDK_KEY_ISO_Enter:
         case GDK_KEY_3270_Enter:
@@ -220,6 +136,7 @@ static gboolean xfcekbd_indicator_key_pressed (GtkWidget        *widget,
         case GDK_KEY_space:
         case GDK_KEY_KP_Space:
             xfcekbd_desktop_config_lock_next_group(&globals.cfg);
+            globals.redraw_queued = TRUE;
             return TRUE;
         default:
             break;
@@ -231,54 +148,22 @@ static gboolean xfcekbd_indicator_key_pressed (GtkWidget        *widget,
 static gboolean
 xfcekbd_indicator_button_pressed (GtkWidget        *widget,
                                   GdkEventButton   *event,
-                                  XfcekbdIndicator *gki)
-{
-    GtkWidget     *img = gtk_bin_get_child (GTK_BIN (widget));
-    GtkAllocation  allocation;
-    gtk_widget_get_allocation (img, &allocation);
-    xkl_debug (150, "Flag img size %d x %d\n", allocation.width, allocation.height);
+                                  XfcekbdIndicator *gki) {
     if (event->button == 1 && event->type == GDK_BUTTON_PRESS) {
         xkl_debug (150, "Mouse button pressed on applet\n");
         xfcekbd_desktop_config_lock_next_group (&globals.cfg);
+        globals.redraw_queued = TRUE;
         return TRUE;
     }
     return FALSE;
 }
 
-static void
-draw_flag (GtkWidget *flag,
-           cairo_t   *cr,
-           GdkPixbuf *image)
-{
-    /* Image width and height */
-    int           iw = gdk_pixbuf_get_width (image);
-    int           ih = gdk_pixbuf_get_height (image);
-    GtkAllocation allocation;
-    double        xwiratio, ywiratio, wiratio;
-
-    gtk_widget_get_allocation (flag, &allocation);
-
-    /* widget-to-image scales, X and Y */
-    xwiratio = 1.0 * allocation.width / iw;
-    ywiratio = 1.0 * allocation.height / ih;
-    wiratio = xwiratio < ywiratio ? xwiratio : ywiratio;
-
-    /* transform cairo context */
-    cairo_translate (cr, allocation.width / 2.0, allocation.height / 2.0);
-    cairo_scale (cr, wiratio, wiratio);
-    cairo_translate (cr, - iw / 2.0, - ih / 2.0);
-
-    gdk_cairo_set_source_pixbuf (cr, image, 0, 0);
-    cairo_paint (cr);
-}
-
 static gchar *
 xfcekbd_indicator_extract_layout_name (int                     group,
                                        XklEngine              *engine,
                                        XfcekbdKeyboardConfig  *kbd_cfg,
                                        gchar                 **short_group_names,
-                                       gchar                 **full_group_names)
-{
+                                       gchar                 **full_group_names) {
     char *layout_name = NULL;
     if (group < g_strv_length (short_group_names)) {
         if (xkl_engine_get_features (engine) & XKLF_MULTIPLE_LAYOUTS_SUPPORTED) {
@@ -286,8 +171,7 @@ xfcekbd_indicator_extract_layout_name (int                     group,
             char *variant_name;
             if (!xfcekbd_keyboard_config_split_items (full_layout_name,
                                                       &layout_name,
-                                                      &variant_name))
-            {
+                                                      &variant_name)) {
                 /* just in case */
                 layout_name = full_layout_name;
             }
@@ -318,8 +202,7 @@ xfcekbd_indicator_extract_layout_name (int                     group,
 static gchar *
 xfcekbd_indicator_create_label_title (int          group,
                                       GHashTable **ln2cnt_map,
-                                      gchar       *layout_name)
-{
+                                      gchar       *layout_name) {
     gpointer  pcounter = NULL;
     char     *prev_layout_name = NULL;
     char     *lbl_title = NULL;
@@ -333,8 +216,7 @@ xfcekbd_indicator_create_label_title (int          group,
     if (g_hash_table_lookup_extended (*ln2cnt_map,
                                       layout_name,
                                       (gpointer *) & prev_layout_name,
-                                      &pcounter))
-    {
+                                      &pcounter)) {
         /* "next" same description */
         gchar appendix[10] = "";
         gint utf8length;
@@ -356,63 +238,46 @@ xfcekbd_indicator_create_label_title (int          group,
 
 static GtkWidget *
 xfcekbd_indicator_prepare_drawing (XfcekbdIndicator *gki,
-                                   int               group)
-{
-    gpointer   pimage;
-    GdkPixbuf *image;
+                                   int               group) {
     GtkWidget *ebox;
 
-    pimage = g_slist_nth_data (globals.images, group);
+    char *lbl_title = NULL;
+    char *layout_name = NULL;
+    GtkWidget *label;
+    static GHashTable *ln2cnt_map = NULL;
+
     ebox = gtk_event_box_new ();
     gtk_event_box_set_visible_window (GTK_EVENT_BOX (ebox), FALSE);
-    if (globals.ind_cfg.show_flags) {
-        GtkWidget *flag;
-        if (pimage == NULL)
-            return NULL;
-        image = GDK_PIXBUF (pimage);
-        flag = gtk_drawing_area_new ();
-        gtk_widget_add_events (GTK_WIDGET (flag),
-                       GDK_BUTTON_PRESS_MASK);
-        g_signal_connect (G_OBJECT (flag), "draw",
-                          G_CALLBACK (draw_flag), image);
-        gtk_container_add (GTK_CONTAINER (ebox), flag);
-    } else {
-        char              *lbl_title = NULL;
-        char              *layout_name = NULL;
-        GtkWidget         *label;
-        static GHashTable *ln2cnt_map = NULL;
 
-        layout_name =
-            xfcekbd_indicator_extract_layout_name (group,
-                                                   globals.engine,
-                                                   &globals.kbd_cfg,
-                                                   globals.short_group_names,
-                                                   globals.full_group_names);
+    layout_name =
+        xfcekbd_indicator_extract_layout_name (group,
+                                                globals.engine,
+                                                &globals.kbd_cfg,
+                                                globals.short_group_names,
+                                                globals.full_group_names);
 
-        lbl_title =
-            xfcekbd_indicator_create_label_title (group,
-                                                  &ln2cnt_map,
-                                                  layout_name);
+    lbl_title =
+        xfcekbd_indicator_create_label_title (group,
+                                                &ln2cnt_map,
+                                                layout_name);
 
-        label = gtk_label_new (lbl_title);
-        gtk_widget_set_halign (label, GTK_ALIGN_CENTER);
-        gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
-        gtk_widget_set_margin_start (label, 2);
-        gtk_widget_set_margin_end (label, 2);
-        gtk_widget_set_margin_top (label, 2);
-        gtk_widget_set_margin_bottom (label, 2);
-        g_free (lbl_title);
-        gtk_label_set_angle (GTK_LABEL (label), gki->priv->angle);
+    label = gtk_label_new (lbl_title);
+    gtk_widget_set_halign (label, GTK_ALIGN_CENTER);
+    gtk_widget_set_valign (label, GTK_ALIGN_CENTER);
+    gtk_widget_set_margin_start (label, 2);
+    gtk_widget_set_margin_end (label, 2);
+    gtk_widget_set_margin_top (label, 2);
+    gtk_widget_set_margin_bottom (label, 2);
+    g_free (lbl_title);
+    gtk_label_set_angle (GTK_LABEL (label), gki->priv->angle);
 
-        if (group + 1 == xkl_engine_get_num_groups (globals.engine))
-        {
-            g_hash_table_destroy (ln2cnt_map);
-            ln2cnt_map = NULL;
-        }
-
-        gtk_container_add (GTK_CONTAINER (ebox), label);
+    if (group + 1 == xkl_engine_get_num_groups (globals.engine)) {
+        g_hash_table_destroy (ln2cnt_map);
+        ln2cnt_map = NULL;
     }
 
+    gtk_container_add (GTK_CONTAINER (ebox), label);
+
     g_signal_connect (G_OBJECT (ebox),
                       "button_press_event",
                       G_CALLBACK (xfcekbd_indicator_button_pressed), gki);
@@ -427,14 +292,12 @@ xfcekbd_indicator_prepare_drawing (XfcekbdIndicator *gki,
 }
 
 static void
-xfcekbd_indicator_update_tooltips (XfcekbdIndicator *gki)
-{
+xfcekbd_indicator_update_tooltips (XfcekbdIndicator *gki) {
     XklState *state = xkl_engine_get_current_state (globals.engine);
     gchar    *buf;
     if (state == NULL ||
             state->group < 0 ||
-            state->group >= g_strv_length (globals.full_group_names))
-    {
+            state->group >= g_strv_length (globals.full_group_names)) {
         return;
     }
 
@@ -446,15 +309,13 @@ xfcekbd_indicator_update_tooltips (XfcekbdIndicator *gki)
 
 static void
 xfcekbd_indicator_parent_set (GtkWidget *gki,
-                              GtkWidget *previous_parent)
-{
+                              GtkWidget *previous_parent) {
     xfcekbd_indicator_update_tooltips (XFCEKBD_INDICATOR (gki));
 }
 
 
 static void
-xfcekbd_indicator_reinit_ui (XfcekbdIndicator *gki)
-{
+xfcekbd_indicator_reinit_ui (XfcekbdIndicator *gki) {
     xfcekbd_indicator_cleanup (gki);
     xfcekbd_indicator_fill (gki);
 
@@ -467,8 +328,7 @@ xfcekbd_indicator_reinit_ui (XfcekbdIndicator *gki)
 static void
 xfcekbd_indicator_cfg_changed (XfconfChannel *channel,
                                gchar         *key,
-                               gpointer       user_data)
-{
+                               gpointer       user_data) {
     xkl_debug (100, "General configuration changed in Xfconf - reiniting...\n");
     xfcekbd_desktop_config_load_from_xfconf (&globals.cfg);
     xfcekbd_desktop_config_activate (&globals.cfg);
@@ -481,11 +341,9 @@ xfcekbd_indicator_cfg_changed (XfconfChannel *channel,
 static void
 xfcekbd_indicator_ind_cfg_changed (XfconfChannel *channel,
                                   gchar          *key,
-                                  gpointer        user_data)
-{
+                                  gpointer        user_data) {
     xkl_debug (100, "Applet configuration changed in Xfconf - reiniting...\n");
     xfcekbd_indicator_config_load_from_xfconf (&globals.ind_cfg);
-    xfcekbd_indicator_update_images ();
     xfcekbd_indicator_config_activate (&globals.ind_cfg);
 
     ForAllIndicators () {
@@ -495,15 +353,13 @@ xfcekbd_indicator_ind_cfg_changed (XfconfChannel *channel,
 
 static void
 xfcekbd_indicator_load_group_names (const gchar **layout_ids,
-                                    const gchar **variant_ids)
-{
+                                    const gchar **variant_ids) {
     if (!xfcekbd_desktop_config_load_group_descriptions (&globals.cfg,
                                                          globals.registry,
                                                          layout_ids,
                                                          variant_ids,
                                                          &globals.short_group_names,
-                                                         &globals.full_group_names))
-    {
+                                                         &globals.full_group_names)) {
         /* We just populate no short names (remain NULL) -
          * full names are going to be used anyway */
         gint i, total_groups = xkl_engine_get_num_groups (globals.engine);
@@ -524,13 +380,11 @@ xfcekbd_indicator_load_group_names (const gchar **layout_ids,
 
 /* Should be called once for all widgets */
 static void
-xfcekbd_indicator_kbd_cfg_callback (XfcekbdIndicator *gki)
-{
+xfcekbd_indicator_kbd_cfg_callback (XfcekbdIndicator *gki) {
     XklConfigRec *xklrec = xkl_config_rec_new ();
     xkl_debug (100, "XKB configuration changed on X Server - reiniting...\n");
 
     xfcekbd_keyboard_config_load_from_x_current (&globals.kbd_cfg, xklrec);
-    xfcekbd_indicator_update_images ();
 
     g_strfreev (globals.full_group_names);
     globals.full_group_names = NULL;
@@ -555,8 +409,7 @@ static void
 xfcekbd_indicator_state_callback (XklEngine            *engine,
                                   XklEngineStateChange  changeType,
                                   gint                  group,
-                                  gboolean              restore)
-{
+                                  gboolean              restore) {
     xkl_debug (150, "group is now %d, restore: %d\n", group, restore);
 
     if (changeType == GROUP_CHANGED) {
@@ -571,8 +424,7 @@ xfcekbd_indicator_state_callback (XklEngine            *engine,
 
 
 void
-xfcekbd_indicator_set_current_page (XfcekbdIndicator *gki)
-{
+xfcekbd_indicator_set_current_page (XfcekbdIndicator *gki) {
     XklState *cur_state;
     cur_state = xkl_engine_get_current_state (globals.engine);
     if (cur_state->group >= 0)
@@ -582,8 +434,7 @@ xfcekbd_indicator_set_current_page (XfcekbdIndicator *gki)
 
 void
 xfcekbd_indicator_set_current_page_for_group (XfcekbdIndicator *gki,
-                                              int               group)
-{
+                                              int               group) {
     xkl_debug (200, "Revalidating for group %d\n", group);
 
     gtk_notebook_set_current_page (GTK_NOTEBOOK (gki), group + 1);
@@ -594,14 +445,16 @@ xfcekbd_indicator_set_current_page_for_group (XfcekbdIndicator *gki,
 /* Should be called once for all widgets */
 static GdkFilterReturn
 xfcekbd_indicator_filter_x_evt (GdkXEvent *xev,
-                                GdkEvent  *event)
-{
+                                GdkEvent  *event) {
     XEvent *xevent = (XEvent *) xev;
 
     xkl_engine_filter_events (globals.engine, xevent);
     switch (xevent->type) {
         case ReparentNotify:
             {
+                if (!globals.redraw_queued)
+                    return GDK_FILTER_CONTINUE;
+
                 XReparentEvent *rne = (XReparentEvent *) xev;
 
                 ForAllIndicators () {
@@ -619,6 +472,8 @@ xfcekbd_indicator_filter_x_evt (GdkXEvent *xev,
                     }
                 }
                 NextIndicator ()
+
+                globals.redraw_queued = FALSE;
             }
             break;
     }
@@ -628,8 +483,7 @@ xfcekbd_indicator_filter_x_evt (GdkXEvent *xev,
 
 /* Should be called once for all widgets */
 static void
-xfcekbd_indicator_start_listen (void)
-{
+xfcekbd_indicator_start_listen (void) {
     gdk_window_add_filter (NULL, (GdkFilterFunc)
                            xfcekbd_indicator_filter_x_evt, NULL);
     gdk_window_add_filter (gdk_get_default_root_window (),
@@ -641,8 +495,7 @@ xfcekbd_indicator_start_listen (void)
 
 /* Should be called once for all widgets */
 static void
-xfcekbd_indicator_stop_listen (void)
-{
+xfcekbd_indicator_stop_listen (void) {
     xkl_engine_stop_listen (globals.engine, XKLL_TRACK_KEYBOARD_STATE);
 
     gdk_window_remove_filter (NULL, (GdkFilterFunc)
@@ -654,19 +507,16 @@ xfcekbd_indicator_stop_listen (void)
 
 static gboolean
 xfcekbd_indicator_scroll (GtkWidget      *gki,
-                          GdkEventScroll *event)
-{
+                          GdkEventScroll *event) {
     /* mouse wheel events should be ignored, otherwise funny effects appear */
     return TRUE;
 }
 
-static void xfcekbd_indicator_init(XfcekbdIndicator *gki)
-{
+static void xfcekbd_indicator_init(XfcekbdIndicator *gki) {
     GtkWidget   *def_drawing;
     GtkNotebook *notebook;
 
-    if (!g_slist_length(globals.widget_instances))
-    {
+    if (!g_slist_length(globals.widget_instances)) {
         xfcekbd_indicator_global_init();
     }
 
@@ -702,8 +552,7 @@ static void xfcekbd_indicator_init(XfcekbdIndicator *gki)
 }
 
 static void
-xfcekbd_indicator_finalize (GObject *obj)
-{
+xfcekbd_indicator_finalize (GObject *obj) {
     XfcekbdIndicator *gki = XFCEKBD_INDICATOR (obj);
     xkl_debug (100,
                "Starting the xfce-kbd-indicator widget shutdown process for %p\n",
@@ -726,8 +575,7 @@ xfcekbd_indicator_finalize (GObject *obj)
 }
 
 static void
-xfcekbd_indicator_global_term (void)
-{
+xfcekbd_indicator_global_term (void) {
     xkl_debug (100, "*** Last  XfcekbdIndicator instance ***\n");
     xfcekbd_indicator_stop_listen ();
 
@@ -746,8 +594,7 @@ xfcekbd_indicator_global_term (void)
 }
 
 static void
-xfcekbd_indicator_class_init (XfcekbdIndicatorClass *klass)
-{
+xfcekbd_indicator_class_init (XfcekbdIndicatorClass *klass) {
     GObjectClass *object_class = G_OBJECT_CLASS (klass);
     GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
@@ -758,6 +605,8 @@ xfcekbd_indicator_class_init (XfcekbdIndicatorClass *klass)
     /* Initing some global vars */
     globals.tooltips_format = "%s";
 
+    globals.redraw_queued = TRUE;
+
     /* Initing vtable */
     object_class->finalize = xfcekbd_indicator_finalize;
 
@@ -774,14 +623,12 @@ xfcekbd_indicator_class_init (XfcekbdIndicatorClass *klass)
 }
 
 static void
-xfcekbd_indicator_global_init (void)
-{
+xfcekbd_indicator_global_init (void) {
     XklConfigRec *xklrec = xkl_config_rec_new ();
 
     globals.engine = xkl_engine_get_instance(GDK_DISPLAY_XDISPLAY(gdk_display_get_default()));
 
-    if (globals.engine == NULL)
-    {
+    if (globals.engine == NULL) {
         xkl_debug (0, "Libxklavier initialization error");
         return;
     }
@@ -817,7 +664,6 @@ xfcekbd_indicator_global_init (void)
     xfcekbd_keyboard_config_load_from_x_current (&globals.kbd_cfg, xklrec);
 
     xfcekbd_indicator_config_load_from_xfconf (&globals.ind_cfg);
-    xfcekbd_indicator_update_images ();
     xfcekbd_indicator_config_activate (&globals.ind_cfg);
 
     xfcekbd_indicator_load_group_names ((const gchar **) xklrec->layouts,
@@ -831,14 +677,12 @@ xfcekbd_indicator_global_init (void)
 }
 
 GtkWidget *
-xfcekbd_indicator_new (void)
-{
+xfcekbd_indicator_new (void) {
     return GTK_WIDGET (g_object_new (xfcekbd_indicator_get_type (), NULL));
 }
 
 void
-xfcekbd_indicator_set_parent_tooltips (XfcekbdIndicator * gki, gboolean spt)
-{
+xfcekbd_indicator_set_parent_tooltips (XfcekbdIndicator * gki, gboolean spt) {
     gki->priv->set_parent_tooltips = spt;
     xfcekbd_indicator_update_tooltips (gki);
 }
